@@ -429,9 +429,9 @@ static int _mapcache_cache_disk_get(mapcache_context *ctx, mapcache_cache *pcach
     size = finfo.size;
     /*
      * at this stage, we have a handle to an open file that contains data.
-     * idealy, we should aquire a read lock, in case the data contained inside the file
+     * idealy, we should acquire a read lock, in case the data contained inside the file
      * is incomplete (i.e. if another process is currently writing to the tile).
-     * currently such a lock is not set, as we don't want to loose performance on tile accesses.
+     * currently such a lock is not set, as we don't want to lose performance on tile accesses.
      * any error that might happen at this stage should only occur if the tile isn't already cached,
      * i.e. normally only once.
      */
@@ -560,7 +560,7 @@ static void _mapcache_cache_disk_set(mapcache_context *ctx, mapcache_cache *pcac
         mapcache_make_parent_dirs(ctx,blankname);
         GC_CHECK_ERROR(ctx);
 
-        /* aquire a lock on the blank file */
+        /* acquire a lock on the blank file */
         isLocked = mapcache_lock_or_wait_for_resource(ctx,ctx->config->locker,blankname, &lock);
 
         if(isLocked == MAPCACHE_TRUE) {
@@ -768,6 +768,7 @@ mapcache_cache* mapcache_cache_disk_create(mapcache_context *ctx)
   cache->cache._tile_set = _mapcache_cache_disk_set;
   cache->cache.configuration_post_config = _mapcache_cache_disk_configuration_post_config;
   cache->cache.configuration_parse_xml = _mapcache_cache_disk_configuration_parse_xml;
+  cache->cache.child_init = mapcache_cache_child_init_noop;
   return (mapcache_cache*)cache;
 }
 
