@@ -753,6 +753,8 @@ void parseCache(mapcache_context *ctx, ezxml_t node, mapcache_cfg *config)
     cache = mapcache_cache_riak_create(ctx);
   } else if(!strcmp(type,"redis")) {
     cache = mapcache_cache_redis_create(ctx);
+  } else if(!strcmp(type,"lmdb")) {
+    cache = mapcache_cache_lmdb_create(ctx);
   } else {
     ctx->set_error(ctx, 400, "unknown cache type %s for cache \"%s\"", type, name);
     return;
