@@ -35,6 +35,24 @@
 #include <unistd.h>
 #endif
 
+typedef struct {
+  mapcache_locker locker;
+
+  /**
+   * directory where lock files will be placed.
+   * Must be readable and writable by the apache user.
+   * Must be placed on a network mounted shared directory if multiple mapcache instances
+   * need to be synchronized
+   */
+  const char *dir;
+} mapcache_locker_disk;
+
+typedef struct {
+    mapcache_locker locker;
+    apr_array_header_t *lockers;
+} mapcache_locker_fallback;
+
+
 #define MAPCACHE_LOCKFILE_PREFIX "_gc_lock"
 
 char* lock_filename_for_resource(mapcache_context *ctx, mapcache_locker_disk *ldisk, const char *resource)
@@ -66,12 +84,12 @@ int mapcache_lock_or_wait_for_resource(mapcache_context *ctx, mapcache_locker *l
     while(rv != MAPCACHE_LOCK_NOENT) {
       unsigned int waited = apr_time_as_msec(apr_time_now()-start_wait);
       if(waited > locker->timeout*1000) {
-        mapcache_unlock_resource(ctx,locker,resource, *lock);
+        mapcache_unlock_resource(ctx,locker,*lock);
         ctx->log(ctx,MAPCACHE_ERROR,"deleting a possibly stale lock after waiting on it for %g seconds",waited/1000.0);
         return MAPCACHE_FALSE;
       }
       apr_sleep(locker->retry_interval * 1000000);
-      rv = locker->ping_lock(ctx,locker,resource, *lock);
+      rv = locker->ping_lock(ctx,locker, *lock);
     }
     return MAPCACHE_FALSE;
   }
@@ -86,9 +104,10 @@ mapcache_lock_result mapcache_locker_disk_aquire_lock(mapcache_context *ctx, map
 
   assert(self->type == MAPCACHE_LOCKER_DISK);
   ldisk = (mapcache_locker_disk*)self;
-  *lock = NULL; /*unused*/
 
   lockname = lock_filename_for_resource(ctx,ldisk,resource);
+  *lock = lockname;
+  
   /* create the lockfile */
   rv = apr_file_open(&lockfile,lockname,APR_WRITE|APR_CREATE|APR_EXCL|APR_XTHREAD,APR_OS_DEFAULT,ctx->pool);
 
@@ -114,12 +133,11 @@ mapcache_lock_result mapcache_locker_disk_aquire_lock(mapcache_context *ctx, map
   }
 }
 
-mapcache_lock_result mapcache_locker_disk_ping_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock) {
+mapcache_lock_result mapcache_locker_disk_ping_lock(mapcache_context *ctx, mapcache_locker *self, void *lock) {
   apr_finfo_t info;
   apr_status_t rv;
   char *lockname;
-  mapcache_locker_disk *ldisk = (mapcache_locker_disk*)self;
-  lockname = lock_filename_for_resource(ctx,ldisk,resource);
+  lockname = (char*)lock;
   rv = apr_stat(&info,lockname,0,ctx->pool);
   if(APR_STATUS_IS_ENOENT(rv)) {
     return MAPCACHE_LOCK_NOENT;
@@ -128,15 +146,14 @@ mapcache_lock_result mapcache_locker_disk_ping_lock(mapcache_context *ctx, mapca
   }
 }
 
-void mapcache_locker_disk_release_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock)
+void mapcache_locker_disk_release_lock(mapcache_context *ctx, mapcache_locker *self, void *lock)
 {
-  mapcache_locker_disk *ld = (mapcache_locker_disk*)self;
-  char *lockname = lock_filename_for_resource(ctx,ld,resource);
+  char *lockname = (char*)lock;
   apr_file_remove(lockname,ctx->pool);
 }
 
-void mapcache_unlock_resource(mapcache_context *ctx, mapcache_locker *locker, char *resource, void *lock) {
-  locker->release_lock(ctx, locker, resource, lock);
+void mapcache_unlock_resource(mapcache_context *ctx, mapcache_locker *locker, void *lock) {
+  locker->release_lock(ctx, locker, lock);
 }
 
 void mapcache_locker_disk_parse_xml(mapcache_context *ctx, mapcache_locker *self, ezxml_t doc) {
@@ -165,14 +182,14 @@ struct mapcache_locker_fallback_lock {
   void *lock; /*the opaque lock returned by the locker*/
 };
 
-void mapcache_locker_fallback_release_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock) {
+void mapcache_locker_fallback_release_lock(mapcache_context *ctx, mapcache_locker *self, void *lock) {
   struct mapcache_locker_fallback_lock *flock = lock;
-  flock->locker->release_lock(ctx,flock->locker,resource,flock->lock);
+  flock->locker->release_lock(ctx,flock->locker,flock->lock);
 }
 
-mapcache_lock_result mapcache_locker_fallback_ping_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock) {
+mapcache_lock_result mapcache_locker_fallback_ping_lock(mapcache_context *ctx, mapcache_locker *self, void *lock) {
   struct mapcache_locker_fallback_lock *flock = lock;
-  return flock->locker->ping_lock(ctx,flock->locker,resource,flock->lock);
+  return flock->locker->ping_lock(ctx,flock->locker,flock->lock);
 }
 
 mapcache_lock_result mapcache_locker_fallback_aquire_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void **lock) {
@@ -215,6 +232,20 @@ void mapcache_locker_fallback_parse_xml(mapcache_context *ctx, mapcache_locker *
 }
 
 #ifdef USE_MEMCACHE
+
+#include <apr_memcache.h>
+
+typedef struct {
+  char *host;
+  int port;
+} mapcache_locker_memcache_server;
+
+typedef struct {
+  mapcache_locker locker;
+  int nservers;
+  mapcache_locker_memcache_server *servers;
+} mapcache_locker_memcache;
+
 void mapcache_locker_memcache_parse_xml(mapcache_context *ctx, mapcache_locker *self, ezxml_t doc) {
   mapcache_locker_memcache *lm = (mapcache_locker_memcache*)self;
   ezxml_t node,server_node;
@@ -288,16 +319,19 @@ apr_memcache_t* create_memcache(mapcache_context *ctx, mapcache_locker_memcache
   return memcache;
 }
 
-mapcache_lock_result mapcache_locker_memcache_ping_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock) {
+typedef struct {
+  apr_memcache_t *memcache;
+  char *lockname;
+} mapcache_lock_memcache;
+
+mapcache_lock_result mapcache_locker_memcache_ping_lock(mapcache_context *ctx, mapcache_locker *self, void *lock) {
   apr_status_t rv;
   char *one;
   size_t ione;
-  mapcache_locker_memcache *lm = (mapcache_locker_memcache*)self;
-  char *key = memcache_key_for_resource(ctx, lm, resource);
-  apr_memcache_t *memcache = (apr_memcache_t*)lock;
-  if(!memcache)
+  mapcache_lock_memcache *mlock = (mapcache_lock_memcache*)lock;
+  if(!mlock || !mlock->lockname || !mlock->memcache)
     return MAPCACHE_LOCK_NOENT;
-  rv = apr_memcache_getp(memcache,ctx->pool,key,&one,&ione,NULL);
+  rv = apr_memcache_getp(mlock->memcache,ctx->pool,mlock->lockname,&one,&ione,NULL);
   if(rv == APR_SUCCESS)
     return MAPCACHE_LOCK_LOCKED;
   else
@@ -309,13 +343,14 @@ mapcache_lock_result mapcache_locker_memcache_aquire_lock(mapcache_context *ctx,
   apr_status_t rv;
   mapcache_locker_memcache *lm = (mapcache_locker_memcache*)self;
   char errmsg[120];
-  char *key = memcache_key_for_resource(ctx, lm, resource);
-  apr_memcache_t *memcache = create_memcache(ctx,lm);
+  mapcache_lock_memcache *mlock = apr_pcalloc(ctx->pool, sizeof(mapcache_lock_memcache));
+  mlock->lockname = memcache_key_for_resource(ctx, lm, resource);
+  mlock->memcache = create_memcache(ctx,lm);
   if(GC_HAS_ERROR(ctx)) {
     return MAPCACHE_LOCK_NOENT;
   }
-  *lock = memcache;
-  rv = apr_memcache_add(memcache,key,"1",1,self->timeout,0);
+  *lock = mlock;
+  rv = apr_memcache_add(mlock->memcache,mlock->lockname,"1",1,self->timeout,0);
   if( rv == APR_SUCCESS) {
     return MAPCACHE_LOCK_AQUIRED;
   } else if ( rv == APR_EEXIST ) {
@@ -326,20 +361,18 @@ mapcache_lock_result mapcache_locker_memcache_aquire_lock(mapcache_context *ctx,
   }
 }
 
-void mapcache_locker_memcache_release_lock(mapcache_context *ctx, mapcache_locker *self, char *resource, void *lock) {
+void mapcache_locker_memcache_release_lock(mapcache_context *ctx, mapcache_locker *self, void *lock) {
   apr_status_t rv;
-  mapcache_locker_memcache *lm = (mapcache_locker_memcache*)self;
+  mapcache_lock_memcache *mlock = (mapcache_lock_memcache*)lock;
   char errmsg[120];
-  char *key = memcache_key_for_resource(ctx, lm, resource);
-  apr_memcache_t *memcache = (apr_memcache_t*)lock;
-  if(!memcache) {
+  if(!mlock || !mlock->memcache || !mlock->lockname) {
     /*error*/
     return;
   }
 
-  rv = apr_memcache_delete(memcache,key,0);
+  rv = apr_memcache_delete(mlock->memcache,mlock->lockname,0);
   if(rv != APR_SUCCESS && rv!= APR_NOTFOUND) {
-    ctx->set_error(ctx,500,"memcache: failed to delete key %s: %s", key, apr_strerror(rv,errmsg,120));
+    ctx->set_error(ctx,500,"memcache: failed to delete key %s: %s", mlock->lockname, apr_strerror(rv,errmsg,120));
   }
 
 }
@@ -370,6 +403,36 @@ mapcache_locker* mapcache_locker_fallback_create(mapcache_context *ctx) {
   return l;
 }
 
+void mapcache_config_parse_locker_old(mapcache_context *ctx, ezxml_t doc, mapcache_cfg *config) {
+  /* backwards compatibility */
+  int micro_retry;
+  ezxml_t node;
+  mapcache_locker_disk *ldisk;
+  config->locker = mapcache_locker_disk_create(ctx);
+  ldisk = (mapcache_locker_disk*)config->locker;
+  if((node = ezxml_child(doc,"lock_dir")) != NULL) {
+    ldisk->dir = apr_pstrdup(ctx->pool, node->txt);
+  } else {
+    ldisk->dir = apr_pstrdup(ctx->pool,"/tmp");
+  }
+
+  if((node = ezxml_child(doc,"lock_retry")) != NULL) {
+    char *endptr;
+    micro_retry = strtol(node->txt,&endptr,10);
+    if(*endptr != 0 || micro_retry <= 0) {
+      ctx->set_error(ctx, 400, "failed to parse lock_retry microseconds \"%s\". Expecting a positive integer",
+          node->txt);
+      return;
+    }
+  } else {
+    /* default retry interval is 1/100th of a second, i.e. 10000 microseconds */
+    micro_retry = 10000;
+  }
+  config->locker->retry_interval = micro_retry / 1000000.0;
+  config->locker->timeout=120;
+}
+
+
 void mapcache_config_parse_locker(mapcache_context *ctx, ezxml_t node, mapcache_locker **locker) {
   ezxml_t cur_node;
   const char *ltype = ezxml_attr(node, "type");
